==> chaosmesh-model-6.3.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/PhysicalMachineSelectorSpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import io.fabric8.kubernetes.api.model.LabelSelectorRequirement;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PhysicalMachineSelectorSpecFluentImpl<A extends PhysicalMachineSelectorSpecFluent<A>> extends BaseFluent<A> implements PhysicalMachineSelectorSpecFluent<A>{
  public PhysicalMachineSelectorSpecFluentImpl() {
  }
  public PhysicalMachineSelectorSpecFluentImpl(PhysicalMachineSelectorSpec instance) {
    this.withAnnotationSelectors(instance.getAnnotationSelectors()); 
    this.withExpressionSelectors(instance.getExpressionSelectors()); 
    this.withFieldSelectors(instance.getFieldSelectors()); 
    this.withLabelSelectors(instance.getLabelSelectors()); 
    this.withNamespaces(instance.getNamespaces()); 
    this.withPhysicalMachines(instance.getPhysicalMachines()); 
  }
  private Map<String,String> annotationSelectors;
  private List<LabelSelectorRequirement> expressionSelectors = new ArrayList<LabelSelectorRequirement>();
  private Map<String,String> fieldSelectors;
  private Map<String,String> labelSelectors;
  private List<String> namespaces = new ArrayList<String>();
  private Map<String,List<String>> physicalMachines;
  public A addToAnnotationSelectors(String key,String value) {
    if(this.annotationSelectors == null && key != null && value != null) { this.annotationSelectors = new LinkedHashMap(); }
    if(key != null && value != null) {this.annotationSelectors.put(key, value);} return (A)this;
  }
  public A addToAnnotationSelectors(Map<String,String> map) {
    if(this.annotationSelectors == null && map != null) { this.annotationSelectors = new LinkedHashMap(); }
    if(map != null) { this.annotationSelectors.putAll(map);} return (A)this;
  }
  public A removeFromAnnotationSelectors(String key) {
    if(this.annotationSelectors == null) { return (A) this; }
    if(key != null && this.annotationSelectors != null) {this.annotationSelectors.remove(key);} return (A)this;
  }
  public A removeFromAnnotationSelectors(Map<String,String> map) {
    if(this.annotationSelectors == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.annotationSelectors != null){this.annotationSelectors.remove(key);}}} return (A)this;
  }
  public Map<String,String> getAnnotationSelectors() {
    return this.annotationSelectors;
  }
  public <K,V>A withAnnotationSelectors(Map<String,String> annotationSelectors) {
    if (annotationSelectors == null) { this.annotationSelectors =  null;} else {this.annotationSelectors = new LinkedHashMap(annotationSelectors);} return (A) this;
  }
  public Boolean hasAnnotationSelectors() {
    return this.annotationSelectors != null;
  }
  public A addToExpressionSelectors(Integer index,LabelSelectorRequirement item) {
    if (this.expressionSelectors == null) {this.expressionSelectors = new ArrayList<LabelSelectorRequirement>();}
    this.expressionSelectors.add(index, item);
    return (A)this;
  }
  public A setToExpressionSelectors(Integer index,LabelSelectorRequirement item) {
    if (this.expressionSelectors == null) {this.expressionSelectors = new ArrayList<LabelSelectorRequirement>();}
    this.expressionSelectors.set(index, item); return (A)this;
  }
  public A addToExpressionSelectors(io.fabric8.kubernetes.api.model.LabelSelectorRequirement... items) {
    if (this.expressionSelectors == null) {this.expressionSelectors = new ArrayList<LabelSelectorRequirement>();}
    for (LabelSelectorRequirement item : items) {this.expressionSelectors.add(item);} return (A)this;
  }
  public A addAllToExpressionSelectors(Collection<LabelSelectorRequirement> items) {
    if (this.expressionSelectors == null) {this.expressionSelectors = new ArrayList<LabelSelectorRequirement>();}
    for (LabelSelectorRequirement item : items) {this.expressionSelectors.add(item);} return (A)this;
  }
  public A removeFromExpressionSelectors(io.fabric8.kubernetes.api.model.LabelSelectorRequirement... items) {
    for (LabelSelectorRequirement item : items) {if (this.expressionSelectors!= null){ this.expressionSelectors.remove(item);}} return (A)this;
  }
  public A removeAllFromExpressionSelectors(Collection<LabelSelectorRequirement> items) {
    for (LabelSelectorRequirement item : items) {if (this.expressionSelectors!= null){ this.expressionSelectors.remove(item);}} return (A)this;
  }
  public List<LabelSelectorRequirement> getExpressionSelectors() {
    return this.expressionSelectors;
  }
  public LabelSelectorRequirement getExpressionSelector(Integer index) {
    return this.expressionSelectors.get(index);
  }
  public LabelSelectorRequirement getFirstExpressionSelector() {
    return this.expressionSelectors.get(0);
  }
  public LabelSelectorRequirement getLastExpressionSelector() {
    return this.expressionSelectors.get(expressionSelectors.size() - 1);
  }
  public LabelSelectorRequirement getMatchingExpressionSelector(Predicate<LabelSelectorRequirement> predicate) {
    for (LabelSelectorRequirement item: expressionSelectors) { if(predicate.test(item)){ return item;} } return null;
  }
  public Boolean hasMatchingExpressionSelector(Predicate<LabelSelectorRequirement> predicate) {
    for (LabelSelectorRequirement item: expressionSelectors) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withExpressionSelectors(List<LabelSelectorRequirement> expressionSelectors) {
    if (expressionSelectors != null) {this.expressionSelectors = new ArrayList(); for (LabelSelectorRequirement item : expressionSelectors){this.addToExpressionSelectors(item);}} else { this.expressionSelectors = null;} return (A) this;
  }
  public A withExpressionSelectors(io.fabric8.kubernetes.api.model.LabelSelectorRequirement... expressionSelectors) {
    if (this.expressionSelectors != null) {this.expressionSelectors.clear();}
    if (expressionSelectors != null) {for (LabelSelectorRequirement item :expressionSelectors){ this.addToExpressionSelectors(item);}} return (A) this;
  }
  public Boolean hasExpressionSelectors() {
    return expressionSelectors != null && !expressionSelectors.isEmpty();
  }
  public A addToFieldSelectors(String key,String value) {
    if(this.fieldSelectors == null && key != null && value != null) { this.fieldSelectors = new LinkedHashMap(); }
    if(key != null && value != null) {this.fieldSelectors.put(key, value);} return (A)this;
  }
  public A addToFieldSelectors(Map<String,String> map) {
    if(this.fieldSelectors == null && map != null) { this.fieldSelectors = new LinkedHashMap(); }
    if(map != null) { this.fieldSelectors.putAll(map);} return (A)this;
  }
  public A removeFromFieldSelectors(String key) {
    if(this.fieldSelectors == null) { return (A) this; }
    if(key != null && this.fieldSelectors != null) {this.fieldSelectors.remove(key);} return (A)this;
  }
  public A removeFromFieldSelectors(Map<String,String> map) {
    if(this.fieldSelectors == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.fieldSelectors != null){this.fieldSelectors.remove(key);}}} return (A)this;
  }
  public Map<String,String> getFieldSelectors() {
    return this.fieldSelectors;
  }
  public <K,V>A withFieldSelectors(Map<String,String> fieldSelectors) {
    if (fieldSelectors == null) { this.fieldSelectors =  null;} else {this.fieldSelectors = new LinkedHashMap(fieldSelectors);} return (A) this;
  }
  public Boolean hasFieldSelectors() {
    return this.fieldSelectors != null;
  }
  public A addToLabelSelectors(String key,String value) {
    if(this.labelSelectors == null && key != null && value != null) { this.labelSelectors = new LinkedHashMap(); }
    if(key != null && value != null) {this.labelSelectors.put(key, value);} return (A)this;
  }
  public A addToLabelSelectors(Map<String,String> map) {
    if(this.labelSelectors == null && map != null) { this.labelSelectors = new LinkedHashMap(); }
    if(map != null) { this.labelSelectors.putAll(map);} return (A)this;
  }
  public A removeFromLabelSelectors(String key) {
    if(this.labelSelectors == null) { return (A) this; }
    if(key != null && this.labelSelectors != null) {this.labelSelectors.remove(key);} return (A)this;
  }
  public A removeFromLabelSelectors(Map<String,String> map) {
    if(this.labelSelectors == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.labelSelectors != null){this.labelSelectors.remove(key);}}} return (A)this;
  }
  public Map<String,String> getLabelSelectors() {
    return this.labelSelectors;
  }
  public <K,V>A withLabelSelectors(Map<String,String> labelSelectors) {
    if (labelSelectors == null) { this.labelSelectors =  null;} else {this.labelSelectors = new LinkedHashMap(labelSelectors);} return (A) this;
  }
  public Boolean hasLabelSelectors() {
    return this.labelSelectors != null;
  }
  public A addToNamespaces(Integer index,String item) {
    if (this.namespaces == null) {this.namespaces = new ArrayList<String>();}
    this.namespaces.add(index, item);
    return (A)this;
  }
  public A setToNamespaces(Integer index,String item) {
    if (this.namespaces == null) {this.namespaces = new ArrayList<String>();}
    this.namespaces.set(index, item); return (A)this;
  }
  public A addToNamespaces(java.lang.String... items) {
    if (this.namespaces == null) {this.namespaces = new ArrayList<String>();}
    for (String item : items) {this.namespaces.add(item);} return (A)this;
  }
  public A addAllToNamespaces(Collection<String> items) {
    if (this.namespaces == null) {this.namespaces = new ArrayList<String>();}
    for (String item : items) {this.namespaces.add(item);} return (A)this;
  }
  public A removeFromNamespaces(java.lang.String... items) {
    for (String item : items) {if (this.namespaces!= null){ this.namespaces.remove(item);}} return (A)this;
  }
  public A removeAllFromNamespaces(Collection<String> items) {
    for (String item : items) {if (this.namespaces!= null){ this.namespaces.remove(item);}} return (A)this;
  }
  public List<String> getNamespaces() {
    return this.namespaces;
  }
  public String getNamespace(Integer index) {
    return this.namespaces.get(index);
  }
  public String getFirstNamespace() {
    return this.namespaces.get(0);
  }
  public String getLastNamespace() {
    return this.namespaces.get(namespaces.size() - 1);
  }
  public String getMatchingNamespace(Predicate<String> predicate) {
    for (String item: namespaces) { if(predicate.test(item)){ return item;} } return null;
  }
  public Boolean hasMatchingNamespace(Predicate<String> predicate) {
    for (String item: namespaces) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withNamespaces(List<String> namespaces) {
    if (namespaces != null) {this.namespaces = new ArrayList(); for (String item : namespaces){this.addToNamespaces(item);}} else { this.namespaces = null;} return (A) this;
  }
  public A withNamespaces(java.lang.String... namespaces) {
    if (this.namespaces != null) {this.namespaces.clear();}
    if (namespaces != null) {for (String item :namespaces){ this.addToNamespaces(item);}} return (A) this;
  }
  public Boolean hasNamespaces() {
    return namespaces != null && !namespaces.isEmpty();
  }
  public A addToPhysicalMachines(String key,List<String> value) {
    if(this.physicalMachines == null && key != null && value != null) { this.physicalMachines = new LinkedHashMap(); }
    if(key != null && value != null) {this.physicalMachines.put(key, value);} return (A)this;
  }
  public A addToPhysicalMachines(Map<String,List<String>> map) {
    if(this.physicalMachines == null && map != null) { this.physicalMachines = new LinkedHashMap(); }
    if(map != null) { this.physicalMachines.putAll(map);} return (A)this;
  }
  public A removeFromPhysicalMachines(String key) {
    if(this.physicalMachines == null) { return (A) this; }
    if(key != null && this.physicalMachines != null) {this.physicalMachines.remove(key);} return (A)this;
  }
  public A removeFromPhysicalMachines(Map<String,List<String>> map) {
    if(this.physicalMachines == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.physicalMachines != null){this.physicalMachines.remove(key);}}} return (A)this;
  }
  public Map<String,List<String>> getPhysicalMachines() {
    return this.physicalMachines;
  }
  public <K,V>A withPhysicalMachines(Map<String,List<String>> physicalMachines) {
    if (physicalMachines == null) { this.physicalMachines =  null;} else {this.physicalMachines = new LinkedHashMap(physicalMachines);} return (A) this;
  }
  public Boolean hasPhysicalMachines() {
    return this.physicalMachines != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PhysicalMachineSelectorSpecFluentImpl that = (PhysicalMachineSelectorSpecFluentImpl) o;
    if (annotationSelectors != null ? !annotationSelectors.equals(that.annotationSelectors) :that.annotationSelectors != null) return false;
    if (expressionSelectors != null ? !expressionSelectors.equals(that.expressionSelectors) :that.expressionSelectors != null) return false;
    if (fieldSelectors != null ? !fieldSelectors.equals(that.fieldSelectors) :that.fieldSelectors != null) return false;
    if (labelSelectors != null ? !labelSelectors.equals(that.labelSelectors) :that.labelSelectors != null) return false;
    if (namespaces != null ? !namespaces.equals(that.namespaces) :that.namespaces != null) return false;
    if (physicalMachines != null ? !physicalMachines.equals(that.physicalMachines) :that.physicalMachines != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(annotationSelectors,  expressionSelectors,  fieldSelectors,  labelSelectors,  namespaces,  physicalMachines,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (annotationSelectors != null && !annotationSelectors.isEmpty()) { sb.append("annotationSelectors:"); sb.append(annotationSelectors + ","); }
    if (expressionSelectors != null && !expressionSelectors.isEmpty()) { sb.append("expressionSelectors:"); sb.append(expressionSelectors + ","); }
    if (fieldSelectors != null && !fieldSelectors.isEmpty()) { sb.append("fieldSelectors:"); sb.append(fieldSelectors + ","); }
    if (labelSelectors != null && !labelSelectors.isEmpty()) { sb.append("labelSelectors:"); sb.append(labelSelectors + ","); }
    if (namespaces != null && !namespaces.isEmpty()) { sb.append("namespaces:"); sb.append(namespaces + ","); }
    if (physicalMachines != null && !physicalMachines.isEmpty()) { sb.append("physicalMachines:"); sb.append(physicalMachines); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> chaosmesh-model-6.7.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/PhysicalMachineSelectorSpecFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import io.fabric8.kubernetes.api.model.LabelSelectorRequirement;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PhysicalMachineSelectorSpecFluentImpl<A extends PhysicalMachineSelectorSpecFluent<A>> extends BaseFluent<A> implements PhysicalMachineSelectorSpecFluent<A>{
  public PhysicalMachineSelectorSpecFluentImpl() {
  }
  public PhysicalMachineSelectorSpecFluentImpl(PhysicalMachineSelectorSpec instance) {
    if (instance != null) {
      this.withAnnotationSelectors(instance.getAnnotationSelectors());
      this.withExpressionSelectors(instance.getExpressionSelectors());
      this.withFieldSelectors(instance.getFieldSelectors());
      this.withLabelSelectors(instance.getLabelSelectors());
      this.withNamespaces(instance.getNamespaces());
      this.withPhysicalMachines(instance.getPhysicalMachines());
    }
  }
  private Map<String,String> annotationSelectors;
  private List<LabelSelectorRequirement> expressionSelectors = new ArrayList<LabelSelectorRequirement>();
  private Map<String,String> fieldSelectors;
  private Map<String,String> labelSelectors;
  private List<String> namespaces = new ArrayList<String>();
  private Map<String,List<String>> physicalMachines;
  public A addToAnnotationSelectors(String key,String value) {
    if(this.annotationSelectors == null && key != null && value != null) { this.annotationSelectors = new LinkedHashMap(); }
    if(key != null && value != null) {this.annotationSelectors.put(key, value);} return (A)this;
  }
  public A addToAnnotationSelectors(Map<String,String> map) {
    if(this.annotationSelectors == null && map != null) { this.annotationSelectors = new LinkedHashMap(); }
    if(map != null) { this.annotationSelectors.putAll(map);} return (A)this;
  }
  public A removeFromAnnotationSelectors(String key) {
    if(this.annotationSelectors == null) { return (A) this; }
    if(key != null && this.annotationSelectors != null) {this.annotationSelectors.remove(key);} return (A)this;
  }
  public A removeFromAnnotationSelectors(Map<String,String> map) {
    if(this.annotationSelectors == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.annotationSelectors != null){this.annotationSelectors.remove(key);}}} return (A)this;
  }
  public Map<String,String> getAnnotationSelectors() {
    return this.annotationSelectors;
  }
  public <K,V>A withAnnotationSelectors(Map<String,String> annotationSelectors) {
    if (annotationSelectors == null) { this.annotationSelectors =  null;} else {this.annotationSelectors = new LinkedHashMap(annotationSelectors);} return (A) this;
  }
  public Boolean hasAnnotationSelectors() {
    return this.annotationSelectors != null;
  }
  public A addToExpressionSelectors(int index,LabelSelectorRequirement item) {
    if (this.expressionSelectors == null) {this.expressionSelectors = new ArrayList<LabelSelectorRequirement>();}
    this.expressionSelectors.add(index, item);
    return (A)this;
  }
  public A setToExpressionSelectors(int index,LabelSelectorRequirement item) {
    if (this.expressionSelectors == null) {this.expressionSelectors = new ArrayList<LabelSelectorRequirement>();}
    this.expressionSelectors.set(index, item); return (A)this;
  }
  public A addToExpressionSelectors(io.fabric8.kubernetes.api.model.LabelSelectorRequirement... items) {
    if (this.expressionSelectors == null) {this.expressionSelectors = new ArrayList<LabelSelectorRequirement>();}
    for (LabelSelectorRequirement item : items) {this.expressionSelectors.add(item);} return (A)this;
  }
  public A addAllToExpressionSelectors(Collection<LabelSelectorRequirement> items) {
    if (this.expressionSelectors == null) {this.expressionSelectors = new ArrayList<LabelSelectorRequirement>();}
    for (LabelSelectorRequirement item : items) {this.expressionSelectors.add(item);} return (A)this;
  }
  public A removeFromExpressionSelectors(io.fabric8.kubernetes.api.model.LabelSelectorRequirement... items) {
    for (LabelSelectorRequirement item : items) {if (this.expressionSelectors!= null){ this.expressionSelectors.remove(item);}} return (A)this;
  }
  public A removeAllFromExpressionSelectors(Collection<LabelSelectorRequirement> items) {
    for (LabelSelectorRequirement item : items) {if (this.expressionSelectors!= null){ this.expressionSelectors.remove(item);}} return (A)this;
  }
  public List<LabelSelectorRequirement> getExpressionSelectors() {
    return this.expressionSelectors;
  }
  public LabelSelectorRequirement getExpressionSelector(int index) {
    return this.expressionSelectors.get(index);
  }
  public LabelSelectorRequirement getFirstExpressionSelector() {
    return this.expressionSelectors.get(0);
  }
  public LabelSelectorRequirement getLastExpressionSelector() {
    return this.expressionSelectors.get(expressionSelectors.size() - 1);
  }
  public LabelSelectorRequirement getMatchingExpressionSelector(Predicate<LabelSelectorRequirement> predicate) {
    for (LabelSelectorRequirement item: expressionSelectors) { if(predicate.test(item)){ return item;} } return null;
  }
  public Boolean hasMatchingExpressionSelector(Predicate<LabelSelectorRequirement> predicate) {
    for (LabelSelectorRequirement item: expressionSelectors) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withExpressionSelectors(List<LabelSelectorRequirement> expressionSelectors) {
    if (expressionSelectors != null) {this.expressionSelectors = new ArrayList(); for (LabelSelectorRequirement item : expressionSelectors){this.addToExpressionSelectors(item);}} else { this.expressionSelectors = null;} return (A) this;
  }
  public A withExpressionSelectors(io.fabric8.kubernetes.api.model.LabelSelectorRequirement... expressionSelectors) {
    if (this.expressionSelectors != null) {this.expressionSelectors.clear(); _visitables.remove("expressionSelectors"); }
    if (expressionSelectors != null) {for (LabelSelectorRequirement item :expressionSelectors){ this.addToExpressionSelectors(item);}} return (A) this;
  }
  public Boolean hasExpressionSelectors() {
    return expressionSelectors != null && !expressionSelectors.isEmpty();
  }
  public A addToFieldSelectors(String key,String value) {
    if(this.fieldSelectors == null && key != null && value != null) { this.fieldSelectors = new LinkedHashMap(); }
    if(key != null && value != null) {this.fieldSelectors.put(key, value);} return (A)this;
  }
  public A addToFieldSelectors(Map<String,String> map) {
    if(this.fieldSelectors == null && map != null) { this.fieldSelectors = new LinkedHashMap(); }
    if(map != null) { this.fieldSelectors.putAll(map);} return (A)this;
  }
  public A removeFromFieldSelectors(String key) {
    if(this.fieldSelectors == null) { return (A) this; }
    if(key != null && this.fieldSelectors != null) {this.fieldSelectors.remove(key);} return (A)this;
  }
  public A removeFromFieldSelectors(Map<String,String> map) {
    if(this.fieldSelectors == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.fieldSelectors != null){this.fieldSelectors.remove(key);}}} return (A)this;
  }
  public Map<String,String> getFieldSelectors() {
    return this.fieldSelectors;
  }
  public <K,V>A withFieldSelectors(Map<String,String> fieldSelectors) {
    if (fieldSelectors == null) { this.fieldSelectors =  null;} else {this.fieldSelectors = new LinkedHashMap(fieldSelectors);} return (A) this;
  }
  public Boolean hasFieldSelectors() {
    return this.fieldSelectors != null;
  }
  public A addToLabelSelectors(String key,String value) {
    if(this.labelSelectors == null && key != null && value != null) { this.labelSelectors = new LinkedHashMap(); }
    if(key != null && value != null) {this.labelSelectors.put(key, value);} return (A)this;
  }
  public A addToLabelSelectors(Map<String,String> map) {
    if(this.labelSelectors == null && map != null) { this.labelSelectors = new LinkedHashMap(); }
    if(map != null) { this.labelSelectors.putAll(map);} return (A)this;
  }
  public A removeFromLabelSelectors(String key) {
    if(this.labelSelectors == null) { return (A) this; }
    if(key != null && this.labelSelectors != null) {this.labelSelectors.remove(key);} return (A)this;
  }
  public A removeFromLabelSelectors(Map<String,String> map) {
    if(this.labelSelectors == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.labelSelectors != null){this.labelSelectors.remove(key);}}} return (A)this;
  }
  public Map<String,String> getLabelSelectors() {
    return this.labelSelectors;
  }
  public <K,V>A withLabelSelectors(Map<String,String> labelSelectors) {
    if (labelSelectors == null) { this.labelSelectors =  null;} else {this.labelSelectors = new LinkedHashMap(labelSelectors);} return (A) this;
  }
  public Boolean hasLabelSelectors() {
    return this.labelSelectors != null;
  }
  public A addToNamespaces(int index,String item) {
    if (this.namespaces == null) {this.namespaces = new ArrayList<String>();}
    this.namespaces.add(index, item);
    return (A)this;
  }
  public A setToNamespaces(int index,String item) {
    if (this.namespaces == null) {this.namespaces = new ArrayList<String>();}
    this.namespaces.set(index, item); return (A)this;
  }
  public A addToNamespaces(java.lang.String... items) {
    if (this.namespaces == null) {this.namespaces = new ArrayList<String>();}
    for (String item : items) {this.namespaces.add(item);} return (A)this;
  }
  public A addAllToNamespaces(Collection<String> items) {
    if (this.namespaces == null) {this.namespaces = new ArrayList<String>();}
    for (String item : items) {this.namespaces.add(item);} return (A)this;
  }
  public A removeFromNamespaces(java.lang.String... items) {
    for (String item : items) {if (this.namespaces!= null){ this.namespaces.remove(item);}} return (A)this;
  }
  public A removeAllFromNamespaces(Collection<String> items) {
    for (String item : items) {if (this.namespaces!= null){ this.namespaces.remove(item);}} return (A)this;
  }
  public List<String> getNamespaces() {
    return this.namespaces;
  }
  public String getNamespace(int index) {
    return this.namespaces.get(index);
  }
  public String getFirstNamespace() {
    return this.namespaces.get(0);
  }
  public String getLastNamespace() {
    return this.namespaces.get(namespaces.size() - 1);
  }
  public String getMatchingNamespace(Predicate<String> predicate) {
    for (String item: namespaces) { if(predicate.test(item)){ return item;} } return null;
  }
  public Boolean hasMatchingNamespace(Predicate<String> predicate) {
    for (String item: namespaces) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withNamespaces(List<String> namespaces) {
    if (namespaces != null) {this.namespaces = new ArrayList(); for (String item : namespaces){this.addToNamespaces(item);}} else { this.namespaces = null;} return (A) this;
  }
  public A withNamespaces(java.lang.String... namespaces) {
    if (this.namespaces != null) {this.namespaces.clear(); _visitables.remove("namespaces"); }
    if (namespaces != null) {for (String item :namespaces){ this.addToNamespaces(item);}} return (A) this;
  }
  public Boolean hasNamespaces() {
    return namespaces != null && !namespaces.isEmpty();
  }
  public A addToPhysicalMachines(String key,List<String> value) {
    if(this.physicalMachines == null && key != null && value != null) { this.physicalMachines = new LinkedHashMap(); }
    if(key != null && value != null) {this.physicalMachines.put(key, value);} return (A)this;
  }
  public A addToPhysicalMachines(Map<String,List<String>> map) {
    if(this.physicalMachines == null && map != null) { this.physicalMachines = new LinkedHashMap(); }
    if(map != null) { this.physicalMachines.putAll(map);} return (A)this;
  }
  public A removeFromPhysicalMachines(String key) {
    if(this.physicalMachines == null) { return (A) this; }
    if(key != null && this.physicalMachines != null) {this.physicalMachines.remove(key);} return (A)this;
  }
  public A removeFromPhysicalMachines(Map<String,List<String>> map) {
    if(this.physicalMachines == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.physicalMachines != null){this.physicalMachines.remove(key);}}} return (A)this;
  }
  public Map<String,List<String>> getPhysicalMachines() {
    return this.physicalMachines;
  }
  public <K,V>A withPhysicalMachines(Map<String,List<String>> physicalMachines) {
    if (physicalMachines == null) { this.physicalMachines =  null;} else {this.physicalMachines = new LinkedHashMap(physicalMachines);} return (A) this;
  }
  public Boolean hasPhysicalMachines() {
    return this.physicalMachines != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PhysicalMachineSelectorSpecFluentImpl that = (PhysicalMachineSelectorSpecFluentImpl) o;
    if (!java.util.Objects.equals(annotationSelectors, that.annotationSelectors)) return false;

    if (!java.util.Objects.equals(expressionSelectors, that.expressionSelectors)) return false;

    if (!java.util.Objects.equals(fieldSelectors, that.fieldSelectors)) return false;

    if (!java.util.Objects.equals(labelSelectors, that.labelSelectors)) return false;

    if (!java.util.Objects.equals(namespaces, that.namespaces)) return false;

    if (!java.util.Objects.equals(physicalMachines, that.physicalMachines)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(annotationSelectors,  expressionSelectors,  fieldSelectors,  labelSelectors,  namespaces,  physicalMachines,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (annotationSelectors != null && !annotationSelectors.isEmpty()) { sb.append("annotationSelectors:"); sb.append(annotationSelectors + ","); }
    if (expressionSelectors != null && !expressionSelectors.isEmpty()) { sb.append("expressionSelectors:"); sb.append(expressionSelectors + ","); }
    if (fieldSelectors != null && !fieldSelectors.isEmpty()) { sb.append("fieldSelectors:"); sb.append(fieldSelectors + ","); }
    if (labelSelectors != null && !labelSelectors.isEmpty()) { sb.append("labelSelectors:"); sb.append(labelSelectors + ","); }
    if (namespaces != null && !namespaces.isEmpty()) { sb.append("namespaces:"); sb.append(namespaces + ","); }
    if (physicalMachines != null && !physicalMachines.isEmpty()) { sb.append("physicalMachines:"); sb.append(physicalMachines); }
    sb.append("}");
    return sb.toString();
  }
  
}
